complete

Function complete 

pub fn complete(
    line_prefix: &str,
    doc_text: &str,
    src_root: Option<&Path>,
) -> Vec<Completion>
Produce completions for the cursor, given the text of the line up to the cursor, the current document text, and the project source root (if any).